# Copyright 2018 Jacques Supcik, HEIA-FR
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This program gives environmental data using a simple JSON Web Service
"""

from flask import Flask, jsonify
from sense_hat import SenseHat

app = Flask(__name__)

@app.route("/")
def sensors():
    sense = SenseHat()
    sense.clear()
    data = {
        "H": sense.get_humidity(),
        "T": sense.get_temperature_from_humidity(),
        "P": sense.get_pressure(),
    }
    f = open("/sys/class/thermal/thermal_zone0/temp")
    cpu_temp = f.readline()
    f.close()
    data["C"] = int(cpu_temp)/1000
    
    return jsonify(data)



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='heiafr-hydrocontest-sensor_api',
    description='Sensor servers for Telecom Box',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Jacques Supcik',
    author_email='jacques.supcik@hefr.ch',
    version='1.0.2',
    license='Apache License 2.0',

    packages=['heiafr.hydrocontest.sensor_api'],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Flask',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: Apache Software License',
        'Topic :: System :: Monitoring',
        'Programming Language :: Python :: 3',
    ]
)
